# TODO 
This is list of features to implement.

## Features to extract

    - [X] Mean, Median, Mode, VAriance, Standard Deviation 
    - [X] Kurtosis, Skewness, Min, Max, Range, Quantiles, Sum, Total Energy
    - [X] Rolling Mean, Rolling Variance, Expanding Sum, Exponential_moving_average, Sliding_window_entropy
    - [ ] Peak Count, Peak Prominence, Peak Width, Burst Detection, 
